Calculates expected sampling variance of a given $h^2$ from the A matrix of a pedigree, based on the method of Visscher and Goddard 2015 Genetics
Source:R/h2_samp_var.R
h2_samp_var.RdCalculates expected sampling variance of a given $h^2$ from the A matrix of a pedigree, based on the method of Visscher and Goddard 2015 Genetics
Examples
# \donttest{
data(gryphons)
pedigree <- gryphons[, 1:3]
h2_samp_var(pedigree,h2=0.3)
#> 0.3
#> 0.001321648
# }